package com.goomood.phm.service;

import java.util.List;
import com.goomood.phm.domain.TechData;

import javax.servlet.http.HttpServletResponse;

/**
 * 技术资料Service接口
 * 
 * @author goomood
 * @date 2024-11-16
 */
public interface ITechDataService 
{
    /**
     * 查询技术资料
     * 
     * @param id 技术资料主键
     * @return 技术资料
     */
    public TechData selectTechDataById(Long id);

    /**
     * 查询技术资料列表
     * 
     * @param techData 技术资料
     * @return 技术资料集合
     */
    public List<TechData> selectTechDataList(TechData techData);

    /**
     * 新增技术资料
     * 
     * @param techData 技术资料
     * @return 结果
     */
    public int insertTechData(TechData techData);

    /**
     * 修改技术资料
     * 
     * @param techData 技术资料
     * @return 结果
     */
    public int updateTechData(TechData techData);

    /**
     * 批量删除技术资料
     * 
     * @param ids 需要删除的技术资料主键集合
     * @return 结果
     */
    public int deleteTechDataByIds(Long[] ids);

    /**
     * 删除技术资料信息
     * 
     * @param id 技术资料主键
     * @return 结果
     */
    public int deleteTechDataById(Long id);

    /**
     * 根据Id下载对应文件
     * @param oosId
     * @return
     */
    int downloadFile(Long oosId, HttpServletResponse response);
}
